/*
 *      vii - buffer and display outout
 *      Copyright (C) 1991, 1995, 1999, 2005, 2009, 2010 Peter Miller
 *
 *      This program is free software; you can redistribute it and/or modify
 *      it under the terms of the GNU General Public License as published by
 *      the Free Software Foundation; either version 2 of the License, or
 *      (at your option) any later version.
 *
 *      This program is distributed in the hope that it will be useful,
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of
 *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *      GNU General Public License for more details.
 *
 *      You should have received a copy of the GNU General Public License
 *      along with this program. If not, see
 *      <http://www.gnu.org/licenses/>.
 */

#include <lib/ac/stdio.h>
#include <lib/ac/stdlib.h>
#include <lib/ac/unistd.h>
#include <libexplain/output.h>
#include <libexplain/program_name.h>

#include <lib/arglex.h>

#include <lib/option.h>
#include <lib/str.h>
#include <lib/version.h>

#include <vii/term.h>
#include <vii/veneer.h>

enum
{
    arglex_token_execute,
    arglex_token_terminal,
    arglex_token_interval,
};

static arglex_table_ty argtab[] =
{
    { "-Execute", arglex_token_execute },
    { "-Terminal", arglex_token_terminal },
    { "-Interval", arglex_token_interval },
    { 0, 0 } /* end marker */
};


static void
usage(void)
{
    const char      *progname;

    progname = explain_program_name_get();
    fprintf(stderr, "usage: %s [ <option>... ]\n", progname);
    fprintf(stderr, "       %s -Help\n", progname);
    exit(1);
}


int
main(int argc, char **argv)
{
    const char      *command;

    command = 0;
    arglex_init(argc, argv, argtab);
    str_initialize();
    switch (arglex())
    {
    case arglex_token_version:
        version();
        exit(0);
        return 0;

    default:
        break;
    }

    while (arglex_token != arglex_token_eoln)
    {
        switch (arglex_token)
        {
        default:
            explain_output_error
            (
                "misplaced \"%s\" argument",
                arglex_value.alv_string
            );
            usage();

        case arglex_token_execute:
            if (arglex() != arglex_token_string)
                usage();
            if (command)
                explain_output_error_and_die("too many commands specified");
            command = arglex_value.alv_string;
            break;

        case arglex_token_terminal:
            if (arglex() != arglex_token_string)
                usage();
            if (terminal)
            {
                explain_output_error_and_die
                (
                    "too many terminal types specified"
                );
            }
            terminal = arglex_value.alv_string;
            break;

        case arglex_token_interval:
            if (arglex() != arglex_token_number)
                usage();
            sleep_time = arglex_value.alv_number;
            if (sleep_time < 1)
            {
                explain_output_error_and_die
                (
                    "interval must be 1 or more seconds, not %s",
                    arglex_value.alv_string
                );
            }
            break;
        }
        arglex();
    }
    if (!command && isatty(0))
        explain_output_error_and_die("can't take input from a terminal");

    veneer(command);
    exit(0);
    return 0;
}
